@@ -1,11 +1,13 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """ Display accelerometer data once per second """
 
 import time
 import board
-import busio
 import adafruit_lsm303_accel
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 sensor = adafruit_lsm303_accel.LSM303_Accel(i2c)
 
 while True:
